@@ -16,6 +16,13 @@ from ..converters import (
 )
 
 
+class CommandException(Exception):
+    """Is raised when an unknown command is passed to the CLI.
+    Should never be raised in practice."""
+
+    pass
+
+
 _sdf_input_help_text = (
     "The SDF model that is supposed to be converted. "
     "Can either be a file path or a URL."
@@ -79,10 +86,13 @@ def save_model(output_path: str, model: Dict, indent=4):
 
 def save_or_print_model(
     output_path: Optional[str],
-    model: Dict,
+    model: Optional[Dict],
     indent=4,
     print_enabled=True,
 ):
+    if model is None:
+        return
+
     if output_path is not None:
         save_model(output_path, model, indent=indent)
     elif print_enabled:
@@ -147,11 +157,12 @@ def _add_origin_url(parser):
 
 def _add_sdf_arguments(subparser):
     sdf_to_wot_tm = subparser.add_parser(
-        "sdf-to-tm", help="Converts an SDF model and mapping files to a WoT Thing Model"
+        "sdf-to-tm",
+        help="Converts an SDF model and mapping files to one or WoT Thing Models.",
     )
     sdf_to_wot_td = subparser.add_parser(
         "sdf-to-td",
-        help="Converts an SDF model and mapping files to a WoT Thing Description",
+        help="Converts an SDF model and mapping files to one or more WoT Thing Descriptions.",
     )
 
     _add_output_argument(
@@ -172,7 +183,7 @@ def _add_sdf_arguments(subparser):
 def _add_tm_arguments(subparser):
     wot_tm_to_sdf = subparser.add_parser(
         "tm-to-sdf",
-        help="Converts a WoT Thing Description to an SDF model and mapping files",
+        help="Converts a WoT Thing Model to an SDF model and zero or more mapping files.",
     )
     wot_tm_to_wot_td = subparser.add_parser(
         "tm-to-td",
@@ -180,6 +191,7 @@ def _add_tm_arguments(subparser):
     )
 
     _add_mapping_file_output_argument(wot_tm_to_sdf)
+    _add_sdf_infoblock_arguments(wot_tm_to_sdf)
     _add_output_argument(
         wot_tm_to_sdf,
         f"Output path for the converted SDF model and mapping files. {_output_path_help_text_suffix}",
@@ -218,13 +230,16 @@ def _add_tm_arguments(subparser):
 
 def _add_td_arguments(subparser):
     wot_td_to_sdf = subparser.add_parser(
-        "td-to-sdf", help="Converts a WoT Thing Model to an SDF model and mapping files"
+        "td-to-sdf",
+        help="Converts one or more WoT Thing Models to an SDF model and zero or more mapping files.",
     )
     wot_td_to_wot_tm = subparser.add_parser(
-        "td-to-tm", help="Converts a WoT Thing Description to a WoT Thing Model"
+        "td-to-tm",
+        help="Converts one or more WoT Thing Descriptions to one or more WoT Thing Models.",
     )
 
     _add_mapping_file_output_argument(wot_td_to_sdf)
+    _add_sdf_infoblock_arguments(wot_td_to_sdf)
     _add_output_argument(
         wot_td_to_sdf,
         f"Output path for the converted SDF model and mapping files. {_output_path_help_text_suffix}",
@@ -244,12 +259,61 @@ def _add_td_arguments(subparser):
         )
 
 
+def _add_sdf_infoblock_arguments(parser):
+    parser.add_argument(
+        "--title",
+        dest="sdf_title",
+        help="Set the title for the  resulting SDF definitions.",
+    )
+
+    parser.add_argument(
+        "--version",
+        dest="sdf_version",
+        help="Set the version for the  resulting SDF definitions.",
+    )
+
+    parser.add_argument(
+        "--copyright",
+        dest="sdf_copyright",
+        help="Set the copyright for the resulting SDF definitions.",
+    )
+
+    parser.add_argument(
+        "--license",
+        dest="sdf_license",
+        help="Set the license for the resulting SDF definitions.",
+    )
+
+
+def _get_sdf_infoblock(args) -> Optional[Dict]:
+    title = args.sdf_title
+    license = args.sdf_license
+    version = args.sdf_version
+    copyright = args.sdf_copyright
+
+    infoblock = {}
+
+    for key, value in [
+        ("title", title),
+        ("version", version),
+        ("copyright", copyright),
+        ("license", license),
+    ]:
+        if value is not None:
+            infoblock[key] = value
+
+    if len(infoblock) == 0:
+        return None
+
+    return infoblock
+
+
 def parse_arguments(args):
     parser = argparse.ArgumentParser(
         description="Convert from SDF to WoT and vice versa."
     )
 
-    subparser = parser.add_subparsers(dest="command")
+    subparser = parser.add_subparsers(dest="command", required=True)
     _add_sdf_arguments(subparser)
     _add_tm_arguments(subparser)
     _add_td_arguments(subparser)
@@ -271,10 +335,12 @@ def parse_arguments(args):
     return parser.parse_args(args)
 
 
-def _get_origin_url(path: str, url: str):
-    if url:
+def _get_origin_url(path: str, url: Optional[str]):
+    if url is not None:
         return url
-    elif path and (path.startswith("http://") or path.startswith("https://")):
+    elif path is not None and (
+        path.startswith("http://") or path.startswith("https://")
+    ):
         return path
     else:
         return None
@@ -286,6 +352,7 @@ def _handle_from_sdf(args):
     output_path = args.output_path
     mapping_file_input_path = args.mapping_file_input_path
     command = args.command
+    suppress_roundtripping = args.suppress_roundtripping
 
     origin_url = _get_origin_url(input_path, args.origin_url)
     sdf_model = _load_model(input_path)
@@ -297,11 +364,17 @@ def _handle_from_sdf(args):
             sdf_model,
             origin_url=origin_url,
             sdf_mapping_files=sdf_mapping_files,
+            suppress_roundtripping=suppress_roundtripping,
         )
     elif command == "sdf-to-tm":
         output = convert_sdf_to_wot_tm(
-            sdf_model, sdf_mapping_files=sdf_mapping_files, origin_url=origin_url
+            sdf_model,
+            sdf_mapping_files=sdf_mapping_files,
+            origin_url=origin_url,
+            suppress_roundtripping=suppress_roundtripping,
         )
+    else:
+        raise CommandException()
 
     save_or_print_model(output_path, output, indent=indent)
 
@@ -312,31 +385,35 @@ def _handle_from_tm(args):
     command = args.command
     input_path = args.wot_tms
     output_path = args.output_path
+    suppress_roundtripping = args.suppress_roundtripping
 
     thing_models = _load_model_or_collection(input_path, "ThingModel")
     bindings = _load_optional_json_file(args.bindings)
     meta_data = _load_optional_json_file(args.meta_data)
     placeholder_map = _load_optional_json_file(args.placeholder_map)
     if command == "tm-to-sdf":
+        infoblock = _get_sdf_infoblock(args)
         output = convert_wot_tm_to_sdf(
             thing_models,
             placeholder_map=placeholder_map,
+            suppress_roundtripping=suppress_roundtripping,
+            infoblock=infoblock,
         )
+        mapping_file_output_path = args.mapping_file_output_path
         if isinstance(output, dict):
-            save_or_print_model(output_path, output, indent=indent)
+            sdf_model, sdf_mapping_file = output, None
         else:
-            mapping_file_output_path = args.mapping_file_output_path
             sdf_model, sdf_mapping_file = output
 
-            save_or_print_model(output_path, sdf_model, indent=indent)
+        save_or_print_model(output_path, sdf_model, indent=indent)
 
-            print_enabled = output_path is None
-            save_or_print_model(
-                mapping_file_output_path,
-                sdf_mapping_file,
-                indent=indent,
-                print_enabled=print_enabled,
-            )
+        print_enabled = output_path is None
+        save_or_print_model(
+            mapping_file_output_path,
+            sdf_mapping_file,
+            indent=indent,
+            print_enabled=print_enabled,
+        )
 
     elif command == "tm-to-td":
         output = convert_wot_tm_to_wot_td(
@@ -348,10 +425,14 @@ def _handle_from_tm(args):
 
         save_or_print_model(output_path, output, indent=indent)
 
+    else:
+        raise CommandException()
+
 
 def _handle_from_td(args):
     indent = args.indent
     command = args.command
+    suppress_roundtripping = args.suppress_roundtripping
 
     thing_description = _load_model_or_collection(args.wot_tds, "ThingDescription")
     output_path = args.output_path
@@ -359,7 +440,12 @@ def _handle_from_td(args):
         thing_model = convert_wot_td_to_wot_tm(thing_description)
         save_or_print_model(output_path, thing_model, indent=indent)
     elif command == "td-to-sdf":
-        sdf_model, mapping_file = convert_wot_td_to_sdf(thing_description)
+        infoblock = _get_sdf_infoblock(args)
+        sdf_model, mapping_file = convert_wot_td_to_sdf(
+            thing_description,
+            suppress_roundtripping=suppress_roundtripping,
+            infoblock=infoblock,
+        )
         save_or_print_model(output_path, sdf_model, indent=indent)
 
         print_enabled = output_path is None
@@ -369,14 +455,15 @@ def _handle_from_td(args):
             indent=indent,
             print_enabled=print_enabled,
         )
+    else:
+        raise CommandException()
 
 
 def _load_optional_json_file(path: Optional[str]) -> Optional[Dict]:
-    json_data = None
-    if path:
-        json_data = _load_model(path)
+    if path is None:
+        return None
 
-    return json_data
+    return _load_model(path)
 
 
 def use_converter_cli(args):
@@ -387,6 +474,8 @@ def use_converter_cli(args):
         _handle_from_tm(args)
     elif command.startswith("td-to"):
         _handle_from_td(args)
+    else:
+        raise CommandException()
 
 
 def main():  # pragma: no cover
